@@ -22,14 +22,14 @@ from distutils.util import strtobool
 
 
 import re
-VERSIONFILE = os.path.join(os.path.abspath(os.path.dirname(__file__)), '__init__.py')
+VERSIONFILE = os.path.join(
+    os.path.abspath(os.path.dirname(__file__)), '__init__.py'
+)
 verstrline = open(VERSIONFILE, "rt").read()
 VSRE = r"^__version__ = ['\"]([^'\"]*)['\"]"
 mo = re.search(VSRE, verstrline, re.M)
 if mo:
     __version__ = mo.group(1)
-#import pkg_resources
-#__version__ = pkg_resources.require("tmuxp")[0].version
 
 logger = logging.getLogger(__name__)
 
@@ -277,7 +277,9 @@ def load_workspace(config_file, args):
         builder.build()
 
         if 'TMUX' in os.environ:
-            if args.answer_yes or prompt_yes_no('Already inside TMUX, switch to session?'):
+            if args.answer_yes or prompt_yes_no(
+                'Already inside TMUX, switch to session?'
+            ):
                 tmux_env = os.environ.pop('TMUX')
                 builder.session.switch_client()
 
@@ -360,8 +362,13 @@ def command_freeze(args):
     ):
         dest = None
         while not dest:
-            dest_prompt = prompt('Save to: ', os.path.abspath(
-                os.path.join(config_dir, '%s.%s' % (sconf.get('session_name'), config_format))))
+            save_to = os.path.abspath(
+                os.path.join(
+                    config_dir,
+                    '%s.%s' % (sconf.get('session_name'), config_format)
+                )
+            )
+            dest_prompt = prompt('Save to: ', save_to)
             if os.path.exists(dest_prompt):
                 print('%s exists. Pick a new filename.' % dest_prompt)
                 continue
@@ -369,7 +376,7 @@ def command_freeze(args):
             dest = dest_prompt
 
         dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
-        if args.answer_yes or prompt_yes_no('Write to %s?' % dest):
+        if args.answer_yes or prompt_yes_no('Save to %s?' % dest):
             buf = open(dest, 'w')
             buf.write(newconfig)
             buf.close()
@@ -377,8 +384,9 @@ def command_freeze(args):
             print('Saved to %s.' % dest)
     else:
         print(
-            'tmuxp has examples in JSON and YAML format at <http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
-            'View tmuxp docs at <http://tmuxp.readthedocs.org/>'
+            'tmuxp has examples in JSON and YAML format at '
+            '<http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
+            'View tmuxp docs at <http://tmuxp.readthedocs.org/>.'
         )
         sys.exit()
 
@@ -445,7 +453,8 @@ def command_import_teamocil(args):
         output = ''
 
         if not os.path.exists(teamocil_config_dir):
-            output += '# %s: \n\tDirectory doesn\'t exist.\n' % teamocil_config_dir
+            output += '# %s: \n\tDirectory doesn\'t exist.\n' % \
+                teamocil_config_dir
         elif not configs_in_user:
             output += '# %s: \n\tNone found.\n' % teamocil_config_dir
         else:
@@ -503,7 +512,7 @@ def command_import_teamocil(args):
                 dest = dest_prompt
 
             dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
-            if args.answer_yes or prompt_yes_no('Write to %s?' % dest):
+            if args.answer_yes or prompt_yes_no('Save to %s?' % dest):
                 buf = open(dest, 'w')
                 buf.write(newconfig)
                 buf.close()
@@ -511,7 +520,8 @@ def command_import_teamocil(args):
                 print('Saved to %s.' % dest)
         else:
             print(
-                'tmuxp has examples in JSON and YAML format at <http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
+                'tmuxp has examples in JSON and YAML format at '
+                '<http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
                 'View tmuxp docs at <http://tmuxp.readthedocs.org/>'
             )
             sys.exit()
@@ -531,7 +541,8 @@ def command_import_tmuxinator(args):
             output = ''
 
             if not os.path.exists(tmuxinator_config_dir):
-                output += '# %s: \n\tDirectory doesn\'t exist.\n' % tmuxinator_config_dir
+                output += '# %s: \n\tDirectory doesn\'t exist.\n' % \
+                    tmuxinator_config_dir
             elif not configs_in_user:
                 output += '# %s: \n\tNone found.\n' % tmuxinator_config_dir
             else:
@@ -590,7 +601,7 @@ def command_import_tmuxinator(args):
                 dest = dest_prompt
 
             dest = os.path.abspath(os.path.relpath(os.path.expanduser(dest)))
-            if args.answer_yes or prompt_yes_no('Write to %s?' % dest):
+            if args.answer_yes or prompt_yes_no('Save to %s?' % dest):
                 buf = open(dest, 'w')
                 buf.write(newconfig)
                 buf.close()
@@ -598,7 +609,8 @@ def command_import_tmuxinator(args):
                 print('Saved to %s.' % dest)
         else:
             print(
-                'tmuxp has examples in JSON and YAML format at <http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
+                'tmuxp has examples in JSON and YAML format at '
+                '<http://tmuxp.readthedocs.org/en/latest/examples.html>\n'
                 'View tmuxp docs at <http://tmuxp.readthedocs.org/>'
             )
             sys.exit()
@@ -626,30 +638,38 @@ def command_convert(args):
         return
 
     if 'json' in ext:
-        if args.answer_yes or prompt_yes_no('convert to <%s> to yaml?' % (fullfile)):
+        if args.answer_yes or prompt_yes_no(
+            'convert to <%s> to yaml?' % (fullfile)
+        ):
             configparser = kaptan.Kaptan()
             configparser.import_config(configfile)
             newfile = fullfile.replace(ext, '.yaml')
             newconfig = configparser.export(
                 'yaml', indent=2, default_flow_style=False
             )
-            if args.answer_yes or prompt_yes_no('write config to %s?' % (newfile)):
+            if args.answer_yes or prompt_yes_no(
+                'Save config to %s?' % (newfile)
+            ):
                 buf = open(newfile, 'w')
                 buf.write(newconfig)
                 buf.close()
-                print('written new config to %s' % (newfile))
+                print('New config saved to %s' % (newfile))
     elif 'yaml' in ext:
-        if args.answer_yes or prompt_yes_no('convert to <%s> to json?' % (fullfile)):
+        if args.answer_yes or prompt_yes_no(
+            'convert to <%s> to json?' % (fullfile)
+        ):
             configparser = kaptan.Kaptan()
             configparser.import_config(configfile)
             newfile = fullfile.replace(ext, '.json')
             newconfig = configparser.export('json', indent=2)
             print(newconfig)
-            if args.answer_yes or prompt_yes_no('write config to <%s>?' % (newfile)):
+            if args.answer_yes or prompt_yes_no(
+                'Save config to <%s>?' % (newfile)
+            ):
                 buf = open(newfile, 'w')
                 buf.write(newconfig)
                 buf.close()
-                print('written new config to <%s>.' % (newfile))
+                print('New config saved to <%s>.' % (newfile))
 
 
 def command_attach_session(args):
@@ -706,6 +726,7 @@ def command_kill_session(args):
     except exc.TmuxpException as e:
         logger.error(e)
 
+
 def get_parser():
     """Return :py:class:`argparse.ArgumentParser` instance for CLI."""
 
@@ -837,7 +858,9 @@ def get_parser():
         type=str,
         nargs='?',
         help='List config available in working directory and config folder.'
-    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
+    ).completer = ConfigFileCompleter(
+        allowednames=('.yaml', '.json'), directories=False
+    )
     load.set_defaults(callback=command_load)
 
     convert = subparsers.add_parser(
@@ -850,7 +873,9 @@ def get_parser():
         type=str,
         default=None,
         help='Absolute or relative path to config file.'
-    ).completer = ConfigFileCompleter(allowednames=('.yaml', '.json'), directories=False)
+    ).completer = ConfigFileCompleter(
+        allowednames=('.yaml', '.json'), directories=False
+    )
 
     convert.set_defaults(callback=command_convert)
 
@@ -921,6 +946,7 @@ def get_parser():
 
 
 def main():
+    """Main CLI application."""
 
     parser = get_parser()
 
@@ -928,7 +954,9 @@ def main():
 
     args = parser.parse_args()
 
-    setup_logger(level=args.log_level.upper() if 'log_level' in args else 'INFO')
+    setup_logger(
+        level=args.log_level.upper() if 'log_level' in args else 'INFO'
+    )
 
     try:
         util.has_required_tmux_version()
