@@ -3,6 +3,7 @@ from __future__ import absolute_import, division, print_function, with_statement
 
 import os
 import shutil
+import tempfile
 import kaptan
 from .. import config, exc
 from ..util import tmux
@@ -54,13 +55,16 @@ sampleconfigdict = {
 
 class ImportExportTest(TestCase):
 
-    @classmethod
-    def setUpClass(cls):
-        if not os.path.exists(TMUXP_DIR):
-            os.makedirs(TMUXP_DIR)
+    def setUp(self):
+        self.tmp_dir = tempfile.mkdtemp(suffix='tmuxp')
+
+    def tearDown(self):
+        if os.path.isdir(self.tmp_dir):
+            shutil.rmtree(self.tmp_dir)
+        logging.debug('wiped %s' % TMUXP_DIR)
 
     def test_export_json(self):
-        json_config_file = os.path.join(TMUXP_DIR, 'config.json')
+        json_config_file = os.path.join(self.tmp_dir, 'config.json')
 
         configparser = kaptan.Kaptan()
         sampleconfig = config.inline(sampleconfigdict)
@@ -68,16 +72,15 @@ class ImportExportTest(TestCase):
 
         json_config_data = configparser.export('json', indent=2)
 
-        buf = open(json_config_file, 'w')
-        buf.write(json_config_data)
-        buf.close()
+        with open(json_config_file, 'w') as buf:
+            buf.write(json_config_data)
 
         new_config = kaptan.Kaptan()
         new_config_data = new_config.import_config(json_config_file).get()
         self.assertDictEqual(sampleconfigdict, new_config_data)
 
     def test_export_yaml(self):
-        yaml_config_file = os.path.join(TMUXP_DIR, 'config.yaml')
+        yaml_config_file = os.path.join(self.tmp_dir, 'config.yaml')
 
         configparser = kaptan.Kaptan()
         sampleconfig = config.inline(sampleconfigdict)
@@ -86,9 +89,8 @@ class ImportExportTest(TestCase):
         yaml_config_data = configparser.export(
             'yaml', indent=2, default_flow_style=False)
 
-        buf = open(yaml_config_file, 'w')
-        buf.write(yaml_config_data)
-        buf.close()
+        with open(yaml_config_file, 'w') as buf:
+            buf.write(yaml_config_data)
 
         new_config = kaptan.Kaptan()
         new_config_data = new_config.import_config(yaml_config_file).get()
@@ -97,40 +99,33 @@ class ImportExportTest(TestCase):
     def test_scan_config(self):
         configs = []
 
-        garbage_file = os.path.join(TMUXP_DIR, 'config.psd')
-        buf = open(garbage_file, 'w')
-        buf.write('wat')
-        buf.close()
+        garbage_file = os.path.join(self.tmp_dir, 'config.psd')
+        with open(garbage_file, 'w') as buf:
+            buf.write('wat')
 
-        if os.path.exists(TMUXP_DIR):
-            for r, d, f in os.walk(TMUXP_DIR):
+        if os.path.exists(self.tmp_dir):
+            for r, d, f in os.walk(self.tmp_dir):
                 for filela in (x for x in f if x.endswith(('.json', '.ini', 'yaml'))):
                     configs.append(os.path.join(
-                        TMUXP_DIR, filela))
+                        self.tmp_dir, filela))
 
         files = 0
-        if os.path.exists(os.path.join(TMUXP_DIR, 'config.json')):
+        if os.path.exists(os.path.join(self.tmp_dir, 'config.json')):
             files += 1
             self.assertIn(os.path.join(
-                TMUXP_DIR, 'config.json'), configs)
+                self.tmp_dir, 'config.json'), configs)
 
-        if os.path.exists(os.path.join(TMUXP_DIR, 'config.yaml')):
+        if os.path.exists(os.path.join(self.tmp_dir, 'config.yaml')):
             files += 1
             self.assertIn(os.path.join(
-                TMUXP_DIR, 'config.yaml'), configs)
+                self.tmp_dir, 'config.yaml'), configs)
 
-        if os.path.exists(os.path.join(TMUXP_DIR, 'config.ini')):
+        if os.path.exists(os.path.join(self.tmp_dir, 'config.ini')):
             files += 1
-            self.assertIn(os.path.join(TMUXP_DIR, 'config.ini'), configs)
+            self.assertIn(os.path.join(self.tmp_dir, 'config.ini'), configs)
 
         self.assertEqual(len(configs), files)
 
-    @classmethod
-    def tearDownClass(cls):
-        # if os.path.isdir(TMUXP_DIR):
-        #    shutil.rmtree(TMUXP_DIR)
-        logging.debug('wiped %s' % TMUXP_DIR)
-
 
 class ExpandTest(TestCase):
 
