@@ -2,10 +2,12 @@
 from __future__ import absolute_import, division, print_function, with_statement
 
 import os
+import sys
 import logging
 import time
 import kaptan
 from .. import Window, config, exc
+from ..util import unicode
 from ..workspacebuilder import WorkspaceBuilder
 from .helpers import TmuxTestCase
 
@@ -132,7 +134,6 @@ class FocusAndPaneIndexTest(TmuxTestCase):
         s = self.session
         sconfig = kaptan.Kaptan(handler='yaml')
         sconfig = sconfig.import_config(self.yaml_config).get()
-        import sys
 
         builder = WorkspaceBuilder(sconf=sconfig)
 
@@ -247,24 +248,34 @@ class WindowAutomaticRename(TmuxTestCase):
             window_count += 1
             w.select_layout(wconf['layout'])
 
-        w = s.attached_window()
+        self.assertNotEqual(s.get('session_name'), 'tmuxp')
+        w = s.windows[0]
 
         for i in range(30):
-            w = s.attached_window()
-            if w['window_name'] == 'man':
+            if w.get('window_name') != 'man':
                 break
-            time.sleep(.2)
+            time.sleep(.5)
 
-        self.assertEqual(w.get('window_name'), 'man')
+        self.assertNotEqual(w.get('window_name'), 'man')
+
+        pane_base_index = w.show_window_option('pane-base-index', g=True)
+        w.select_pane(pane_base_index)
+
+        for i in range(30):
+            self.session.server._update_windows()
+            if w.get('window_name') == 'man':
+                break
+            time.sleep(.5)
+
+        self.assertEqual(w.get('window_name'), unicode('man'))
 
         w.select_pane('-D')
         for i in range(30):
-            w = s.attached_window()
             if w['window_name'] != 'man':
                 break
-            time.sleep(.2)
+            time.sleep(.5)
 
-        self.assertNotEqual(w.get('window_name'), 'man')
+        self.assertEqual(w.get('window_name'), unicode('man'))
 
 
 class BlankPaneTest(TmuxTestCase):
@@ -342,8 +353,6 @@ class StartDirectoryTest(TmuxTestCase):
         sconfig = config.expand(sconfig)
         sconfig = config.trickle(sconfig)
 
-        logger.error(sconfig)
-
         builder = WorkspaceBuilder(sconf=sconfig)
         builder.build(session=self.session)
 
@@ -352,3 +361,74 @@ class StartDirectoryTest(TmuxTestCase):
             for window in self.session.windows:
                 for p in window.panes:
                     self.assertTrue(p.get('pane_start_path', path))
+
+
+class PaneOrderingTest(TmuxTestCase):
+
+    """Pane ordering based on position in config and ``pane_index``.
+
+    Regression test for https://github.com/tony/tmuxp/issues/15.
+
+    """
+
+    yaml_config = """
+    session_name: sampleconfig
+    start_directory: '~'
+    windows:
+    - options:
+      - automatic_rename: on
+      panes:
+      - cd /var/log
+      - cd /sys
+      - cd /sbin
+      - cd /tmp
+    """
+
+    def test_pane_order(self):
+
+        # test order of `panes` (and pane_index) above aganist pane_dirs
+        pane_paths = [
+            '/var/log',
+            '/sys',
+            '/sbin',
+            '/tmp'
+        ]
+        s = self.session
+        sconfig = kaptan.Kaptan(handler='yaml')
+        sconfig = sconfig.import_config(self.yaml_config).get()
+        sconfig = config.expand(sconfig)
+        sconfig = config.trickle(sconfig)
+
+        builder = WorkspaceBuilder(sconf=sconfig)
+
+        window_count = len(self.session._windows)  # current window count
+        self.assertEqual(len(s._windows), window_count)
+        for w, wconf in builder.iter_create_windows(s):
+            window_pane_count = len(w._panes)
+            for p in builder.iter_create_panes(w, wconf):
+                p = p
+                self.assertEqual(len(s._windows), window_count)
+
+            self.assertIsInstance(w, Window)
+
+            self.assertEqual(len(s._windows), window_count)
+            window_count += 1
+
+        for w in self.session.windows:
+            import time
+            time.sleep(1)
+            pane_base_index = w.show_window_option('pane-base-index', g=True)
+            for p_index, p in enumerate(w.list_panes(), start=pane_base_index):
+                self.assertEqual(int(p_index), int(p.get('pane_index')))
+
+                # pane-base-index start at base-index, pane_paths always start
+                # at 0 since python list.
+                pane_path = pane_paths[p_index - pane_base_index]
+
+                for i in range(30):
+                    p.server._update_panes()
+                    if p.get('pane_current_path') == pane_path:
+                        break
+                    time.sleep(.5)
+
+                self.assertEqual(p.get('pane_current_path'), pane_path)
