@@ -132,6 +132,7 @@ class WorkspaceBuilder(object):
 
         assert(isinstance(session, Session))
 
+        focus = None
         for w, wconf in self.iter_create_windows(session):
             assert(isinstance(w, Window))
             for p in self.iter_create_panes(w, wconf):
@@ -141,6 +142,12 @@ class WorkspaceBuilder(object):
                 if 'layout' in wconf:
                     w.select_layout(wconf['layout'])
 
+            if 'focus' in wconf and wconf['focus']:
+                focus = w
+
+        if focus:
+            focus.select_window()
+
     def iter_create_windows(self, s):
         """Return :class:`Window` iterating through session config dict.
 
@@ -200,13 +207,20 @@ class WorkspaceBuilder(object):
         """
         assert(isinstance(w, Window))
 
-        for pindex, pconf in enumerate(wconf['panes'], start=1):
-            if pindex != int(1):
-                p = w.split_window(attach=False)
+        pane_base_index = int(w.show_window_option('pane-base-index', g=True))
+
+        for pindex, pconf in enumerate(wconf['panes'], start=pane_base_index):
+            if pindex != int(pane_base_index):
+                p = w.split_window(
+                    attach=True,
+                    #target=w.list_panes()[-1].get('pane_index')
+                )
                 assert(isinstance(p, Pane))
+                assert int(p.get('pane_index')) == int(pane_base_index + pindex)
             else:
                 p = w.attached_pane()
                 assert(isinstance(p, Pane))
+                assert int(p.get('pane_index')) == int(pane_base_index)
 
             if 'layout' in wconf:
                 w.select_layout(wconf['layout'])
@@ -242,7 +256,12 @@ def freeze(session):
         wconf['layout'] = w.get('window_layout')
         wconf['panes'] = []
 
-        if all(w.panes[0].get('pane_current_path') == p.get('pane_current_path') for p in w.panes):
+        if (
+            all(
+                w.panes[0].get('pane_current_path') ==
+                p.get('pane_current_path') for p in w.panes
+            )
+        ):
             wconf['start_directory'] = w.panes[0].get('pane_current_path')
 
         for p in w.panes:
@@ -256,8 +275,13 @@ def freeze(session):
 
             current_cmd = p.get('pane_current_command')
 
-            if current_cmd.startswith('-') or \
-                any(current_cmd.endswith(cmd) for cmd in ['python', 'ruby', 'node']):
+            if (
+                current_cmd.startswith('-') or
+                any(
+                    current_cmd.endswith(cmd)
+                    for cmd in ['python', 'ruby', 'node']
+                )
+            ):
                     current_cmd = None
 
             if current_cmd:
